.. OU Container Builder documentation master file, created by
   sphinx-quickstart on Wed Apr 14 14:13:10 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

OU Container Builder
====================

The OU Container Builder is a small command-line application to build a Docker container either for online hosted use
via JupyterHub or for local use with Docker.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   building
   configuration/index
   packs/index
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
